aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/rosa/rosa.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/rosa/rosa.go')
-rw-r--r--internal/rosa/rosa.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/internal/rosa/rosa.go b/internal/rosa/rosa.go
index a28fd836..47ccddab 100644
--- a/internal/rosa/rosa.go
+++ b/internal/rosa/rosa.go
@@ -426,8 +426,8 @@ type Helper interface {
}
const (
- // sourceTarXZ denotes a source tarball to be decompressed using [XZ].
- sourceTarXZ = 1 + iota
+ // SourceKindTarXZ denotes a source tarball to be decompressed using [XZ].
+ SourceKindTarXZ = 1 + iota
)
// PackageAttr holds build-system-agnostic attributes.
@@ -546,7 +546,7 @@ func (t Toolchain) NewPackage(
var sourceSuffix string
switch attr.SourceKind {
- case sourceTarXZ:
+ case SourceKindTarXZ:
sourceSuffix = ".tar.xz"
scriptEarly += `
tar -C /usr/src/ -xf '/usr/src/` + name + `.tar.xz'